@@ -3,6 +3,7 @@ import time
 import io
 from snappi_ixnetwork.timer import Timer
 
+
 class Capture(object):
     """Transforms OpenAPI objects into IxNetwork objects
 
@@ -38,18 +39,18 @@ class Capture(object):
         'src': '26',
         'dst': '30',
     }
-    
+
     _VLAN_OFFSET_MAP = {
         'priority': '34',
         'cfi': '34',
         'id': '34',
         'protocol': '36',
     }
-    
+
     def __init__(self, ixnetworkapi):
         self._api = ixnetworkapi
         self._capture_request = None
-    
+
     def _import(self, imports):
         if len(imports) > 0:
             errata = self._resource_manager.ImportConfig(
@@ -58,7 +59,7 @@ class Capture(object):
                 self._api.warning(item)
             return len(errata) == 0
         return True
-    
+
     def config(self):
         """Overwrite any capture settings
         """
@@ -80,9 +81,12 @@ class Capture(object):
                 continue
             for port_name in capture_item.port_names:
                 capture_mode = 'captureTriggerMode'
-                if capture_item.overwrite:
+                if capture_item.get('overwrite'):
                     capture_mode = 'captureContinuousMode'
-                    reset = {'xpath': vports[port_name]['xpath'] + '/capture/trigger'}
+                    reset = {
+                        'xpath': vports[port_name][
+                            'xpath'] + '/capture/trigger'
+                    }
                     reset['captureTriggerEnable'] = False
                     self._import(reset)
                 capture = {
@@ -100,20 +104,17 @@ class Capture(object):
                     filter['captureFilterEnable'] = True
                     for cap_filter in capture_item.filters:
                         if cap_filter.parent.choice == 'ethernet':
-                            self._config_ethernet_pallette(cap_filter,
-                                                           pallette,
-                                                           trigger,
-                                                           filter)
+                            self._config_ethernet_pallette(
+                                cap_filter, pallette, trigger, filter
+                            )
                         elif cap_filter.parent.choice == 'custom':
-                            self._config_custom_pallete(cap_filter,
-                                                        pallette,
-                                                        trigger,
-                                                        filter)
+                            self._config_custom_pallete(
+                                cap_filter, pallette, trigger, filter
+                            )
                         else:
-                            self._config_missing_pallete(cap_filter,
-                                                        pallette,
-                                                        trigger,
-                                                        filter)
+                            self._config_missing_pallete(
+                                cap_filter, pallette, trigger, filter
+                            )
                 imports.append(capture)
                 imports.append(pallette)
                 imports.append(filter)
@@ -122,33 +123,38 @@ class Capture(object):
 
     def reset_capture_request(self):
         self._capture_request = None
-    
+
     def _config_missing_pallete(self, cap_filter, pallette, trigger, filter):
-        pallete_map = getattr(self, '_{0}_OFFSET_MAP'.format(
-                                cap_filter.parent.choice.upper()))
+        pallete_map = getattr(
+            self, '_{0}_OFFSET_MAP'.format(cap_filter.parent.choice.upper())
+        )
         for field_name in dir(cap_filter):
             if field_name not in pallete_map:
-                raise Exception("Api not implimented for {0}".format(
-                            field_name))
+                raise Exception(
+                    "Api not implimented for {0}".format(field_name)
+                )
             if field_name in pallete_map:
                 cap_field = getattr(cap_filter, field_name)
                 if cap_field.value is not None:
-                    new_pattern = GetPattern(filter.get(
-                                        'captureFilterPattern'))
+                    new_pattern = GetPattern(
+                        filter.get('captureFilterPattern')
+                    )
                     pallette[new_pattern.pattern] = cap_field.value
                     pallette[new_pattern.pattern_offset] = pallete_map[
-                                field_name]
+                        field_name
+                    ]
                     if cap_field.mask is not None:
                         pallette[new_pattern.pattern_mask] = cap_field.mask
                     if cap_field.negate is not None and \
-                        cap_field.negate is True:
+                            cap_field.negate is True:
                         filter['captureFilterPattern'] = 'notPattern1'
                     else:
-                        filter['captureFilterPattern'] = new_pattern.filter_pattern
+                        filter[
+                            'captureFilterPattern'
+                        ] = new_pattern.filter_pattern
                     trigger['triggerFilterPattern'] = filter[
                         'captureFilterPattern']
-                
-                    
+
     def _config_custom_pallete(self, cap_filter, pallette, trigger, filter):
         if cap_filter.value is not None:
             pallette['pattern1'] = cap_filter.value
@@ -196,7 +202,7 @@ class Capture(object):
             self._start_capture()
         elif request.state == 'stop':
             self._stop_capture()
-    
+
     def _start_capture(self):
         with Timer(self._api, 'Captures start'):
             if self._capture_request is None:
@@ -204,8 +210,11 @@ class Capture(object):
             ixn_vports = self._api.select_vports()
             if len(ixn_vports) == 0:
                 raise Exception("Please configure port before start capture")
-            ixn_cap_ports = [name for name, vport in ixn_vports.items()
-                            if vport['capture']['hardwareEnabled'] is True]
+            ixn_cap_ports = [
+                name
+                for name, vport in ixn_vports.items()
+                if vport['capture']['hardwareEnabled'] is True
+            ]
             port_names = self._capture_request.port_names
             if port_names is None or \
                     len(set(ixn_cap_ports) ^ set(port_names)) == 0:
@@ -220,17 +229,20 @@ class Capture(object):
                 url = '%s/vport/capture/operations/start' % \
                       self._api._ixnetwork.href
                 for vport_name, vport in ixn_vports.items():
-                    if vport_name in port_names:
-                        if vport['capture']['hardwareEnabled'] is False:
-                            raise Exception("Please enable capture in %s before start capture"
-                                            %vport_name)
-                        payload = {
-                            'arg1': '{0}/capture'.format(vport['href'])
-                        }
-                        try:
-                            self._api._request('POST', url, payload)
-                        except Exception:
-                            pass
+                    if vport_name not in port_names:
+                        continue
+                    if vport['capture']['hardwareEnabled'] is False:
+                        raise Exception(
+                            "Please enable capture in"
+                            " %s before start capture" % vport_name
+                        )
+                    payload = {
+                        'arg1': '{0}/capture'.format(vport['href'])
+                    }
+                    try:
+                        self._api._request('POST', url, payload)
+                    except Exception:
+                        pass
 
     def _stop_capture(self):
         with Timer(self._api, 'Captures stop'):
@@ -242,40 +254,48 @@ class Capture(object):
                 for vport_name, vport in ixn_vports.items():
                     if vport_name in self._capture_request.port_names:
                         payload['arg1'].append(vport['href'])
-                url = '%s/vport/operations/clearCaptureInfos' % \
-                        self._api._ixnetwork.href
+                url = '{}/vport/operations/clearCaptureInfos'.format(
+                    self._api._ixnetwork.href
+                )
+
                 self._api._request('POST', url, payload)
             else:
                 self._api._ixnetwork.StopCapture()
-                
 
     def results(self, request):
         """Gets capture file and returns it as a byte stream
         """
         with Timer(self._api, 'Captures stop'):
-            capture = self._api._vport.find(Name=self._api.special_char(
-                            request.port_name)).Capture
+            capture = self._api._vport.find(
+                Name=self._api.special_char(request.port_name)
+            ).Capture
             capture.Stop('allTraffic')
 
-            #   Internally setting max time_out to 90sec with 3sec polling interval.
-            #   Todo: Need to discuss and incorporate time_out field within model
+            # Internally setting max time_out to 90sec,
+            #  with 3sec polling interval.
+            # Todo: Need to discuss and incorporate time_out field within model
             retry_count = 30
             port_ready = True
             for x in range(retry_count):
                 port_ready = True
                 time.sleep(3)
-                capture = self._api._vport.find(Name=self._api.special_char(
-                                request.port_name)).Capture
-                if capture.HardwareEnabled and capture.DataCaptureState == 'notReady':
+                capture = self._api._vport.find(
+                    Name=self._api.special_char(request.port_name)).Capture
+                if capture.HardwareEnabled and \
+                        capture.DataCaptureState == 'notReady':
                     port_ready = False
                     continue
-                if capture.SoftwareEnabled and capture.ControlCaptureState == 'notReady':
+                if capture.SoftwareEnabled and \
+                        capture.ControlCaptureState == 'notReady':
                     port_ready = False
                     continue
                 break
             if not port_ready:
-                self._api.warning("Capture was not stopped for this port %s" %
-                             (request.port_name))
+                self._api.warning(
+                    "Capture was not stopped for this port %s" % (
+                        request.port_name
+                    )
+                )
 
         payload = {'arg1': [self._api._vport.href]}
         url = '%s/vport/operations/getCaptureInfos' % self._api._ixnetwork.href
@@ -287,16 +307,18 @@ class Capture(object):
         payload = {'arg1': self._api._vport.href, 'arg2': file_id}
         self._api._request('POST', url, payload)
 
-        url = '%s/vport/operations/releaseCapturePorts' % self._api._ixnetwork.href
+        url = '{}/vport/operations/releaseCapturePorts'.format(
+            self._api._ixnetwork.href)
         payload = {'arg1': [self._api._vport.href]}
         self._api._request('POST', url, payload)
 
         path = '%s/capture' % self._api._ixnetwork.Globals.PersistencePath
-        url = '%s/files?absolute=%s&filename=%s.cap' % (self._api._ixnetwork.href,
-                                                        path, file_name)
+        url = '%s/files?absolute=%s&filename=%s.cap' % (
+            self._api._ixnetwork.href, path, file_name)
         pcap_file_bytes = self._api._request('GET', url)
         return io.BytesIO(pcap_file_bytes)
-        
+
+
 class GetPattern(object):
     """ This is validating captureFilterPattern and return expected patterns
     """
@@ -304,23 +326,23 @@ class GetPattern(object):
         self._new_count = 1
         self.cap_filter_pattern = cap_filter_pattern
         self._validate_pattern(cap_filter_pattern)
-    
+
     def _validate_pattern(self, cap_filter_pattern):
         if cap_filter_pattern is not None:
             self._new_count = 2
-    
+
     @property
     def pattern(self):
         return 'pattern{0}'.format(self._new_count)
-    
+
     @property
     def pattern_mask(self):
         return 'patternMask{0}'.format(self._new_count)
-    
+
     @property
     def pattern_offset(self):
         return 'patternOffset{0}'.format(self._new_count)
-    
+
     @property
     def filter_pattern(self):
         if self._new_count == 1:
@@ -328,5 +350,3 @@ class GetPattern(object):
         else:
             return '{0}AndPattern{1}'.format(self.cap_filter_pattern,
                                              self._new_count)
-        
-        
\ No newline at end of file
